@@ -1,15 +1,18 @@
 from prettytable import PrettyTable
-
+from colored import fg, bg, attr
 from .core import main
 
 import argparse
-import emoji
 
 default_nodes = [
     "https://hived.emre.sh",
     "https://api.hive.blog",
 ]
 
+ok_color = bg('green') + fg('white')
+nok_color = bg('red') + fg('white')
+reset = attr('reset')
+
 
 def runner():
     parser = argparse.ArgumentParser()
@@ -30,7 +33,7 @@ def runner():
                         [f"[{i}]",
                          scan_result["node"],
                          sub_call,
-                         emoji.emojize(":check_mark_button:") if scan_status else emoji.emojize("cross mark"),
+                         ok_color + "OK" + reset if scan_status else nok_color + "NOK" + reset,
                          int(scan_result["time_spent"] * 1e4),
                          scan_result.get("error", "-")]
                     )
